Python ST7735 160x80
====================

Python library to control an ST7735 TFT LCD display. Allows simple
drawing on the display without installing a kernel module.

Designed specifically to work with a ST7735 based 160x80 pixel TFT SPI
display. (Specifically the 0.96" SPI LCD from Pimoroni).

Make sure you have the following dependencies:

::

    sudo apt-get update
    sudo apt-get install python-rpi.gpio python-spidev python-pip python-imaging python-numpy

Install this library by running:

::

    sudo pip install st7735

See example of usage in the examples folder.

Pimoroni invests time and resources forking and slightly modifying this
open source code, please support Pimoroni and open-source software by
purchasing products from us, too!

Adafruit invests time and resources providing this open source code,
please support Adafruit and open-source hardware by purchasing products
from Adafruit!

Modified from 'Modified from 'Adafruit Python ILI9341' written by Tony
DiCola for Adafruit Industries.' written by Clement Skau.

MIT license, all text above must be included in any redistribution
